import * as React from 'react';
import { createPortal } from 'react-dom';
import { useImperativeHandle, useEffect, useMemo, useRef, useContext, forwardRef, memo } from 'react';
import { applyReactStyle } from "../utils/apply-react-style.js";
import { MapContext } from "./map.js";
import { arePointsEqual } from "../utils/deep-equal.js";

function Marker(props, ref) {
  const {
    map,
    mapLib
  } = useContext(MapContext);
  const thisRef = useRef({
    props
  });
  thisRef.current.props = props;
  const marker = useMemo(() => {
    let hasChildren = false;
    React.Children.forEach(props.children, el => {
      if (el) {
        hasChildren = true;
      }
    });
    const options = { ...props,
      element: hasChildren ? document.createElement('div') : null
    };
    const mk = new mapLib.Marker(options);
    mk.setLngLat([props.longitude, props.latitude]);
    mk.getElement().addEventListener('click', e => {
      var _thisRef$current$prop, _thisRef$current$prop2;

      (_thisRef$current$prop = (_thisRef$current$prop2 = thisRef.current.props).onClick) === null || _thisRef$current$prop === void 0 ? void 0 : _thisRef$current$prop.call(_thisRef$current$prop2, {
        type: 'click',
        target: mk,
        originalEvent: e
      });
    });
    mk.on('dragstart', e => {
      var _thisRef$current$prop3, _thisRef$current$prop4;

      const evt = e;
      evt.lngLat = marker.getLngLat();
      (_thisRef$current$prop3 = (_thisRef$current$prop4 = thisRef.current.props).onDragStart) === null || _thisRef$current$prop3 === void 0 ? void 0 : _thisRef$current$prop3.call(_thisRef$current$prop4, evt);
    });
    mk.on('drag', e => {
      var _thisRef$current$prop5, _thisRef$current$prop6;

      const evt = e;
      evt.lngLat = marker.getLngLat();
      (_thisRef$current$prop5 = (_thisRef$current$prop6 = thisRef.current.props).onDrag) === null || _thisRef$current$prop5 === void 0 ? void 0 : _thisRef$current$prop5.call(_thisRef$current$prop6, evt);
    });
    mk.on('dragend', e => {
      var _thisRef$current$prop7, _thisRef$current$prop8;

      const evt = e;
      evt.lngLat = marker.getLngLat();
      (_thisRef$current$prop7 = (_thisRef$current$prop8 = thisRef.current.props).onDragEnd) === null || _thisRef$current$prop7 === void 0 ? void 0 : _thisRef$current$prop7.call(_thisRef$current$prop8, evt);
    });
    return mk;
  }, []);
  useEffect(() => {
    marker.addTo(map.getMap());
    return () => {
      marker.remove();
    };
  }, []);
  const {
    longitude,
    latitude,
    offset,
    style,
    draggable = false,
    popup = null,
    rotation = 0,
    rotationAlignment = 'auto',
    pitchAlignment = 'auto'
  } = props;
  useEffect(() => {
    applyReactStyle(marker.getElement(), style);
  }, [style]);
  useImperativeHandle(ref, () => marker, []);

  if (marker.getLngLat().lng !== longitude || marker.getLngLat().lat !== latitude) {
    marker.setLngLat([longitude, latitude]);
  }

  if (offset && !arePointsEqual(marker.getOffset(), offset)) {
    marker.setOffset(offset);
  }

  if (marker.isDraggable() !== draggable) {
    marker.setDraggable(draggable);
  }

  if (marker.getRotation() !== rotation) {
    marker.setRotation(rotation);
  }

  if (marker.getRotationAlignment() !== rotationAlignment) {
    marker.setRotationAlignment(rotationAlignment);
  }

  if (marker.getPitchAlignment() !== pitchAlignment) {
    marker.setPitchAlignment(pitchAlignment);
  }

  if (marker.getPopup() !== popup) {
    marker.setPopup(popup);
  }

  return createPortal(props.children, marker.getElement());
}

export default memo(forwardRef(Marker));
//# sourceMappingURL=marker.js.map